###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file hu.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:56:13Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::hu;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::hu::ISA = qw(DateTime::Locale::root);

my @day_names = (
"hétfő",
"kedd",
"szerda",
"csütörtök",
"péntek",
"szombat",
"vasárnap",
);

my @day_abbreviations = (
"H",
"K",
"Sze",
"Cs",
"P",
"Szo",
"V",
);

my @day_narrows = (
"H",
"K",
"S",
"C",
"P",
"S",
"V",
);

my @month_names = (
"január",
"február",
"március",
"április",
"május",
"június",
"július",
"augusztus",
"szeptember",
"október",
"november",
"december",
);

my @month_abbreviations = (
"jan\.",
"febr\.",
"márc\.",
"ápr\.",
"máj\.",
"jún\.",
"júl\.",
"aug\.",
"szept\.",
"okt\.",
"nov\.",
"dec\.",
);

my @month_narrows = (
"J",
"F",
"M",
"Á",
"M",
"J",
"J",
"A",
"S",
"O",
"N",
"D",
);

my @am_pms = (
"DE",
"DU",
);

my @eras = (
"i\.e\.",
"i\.u\.",
);

my $date_parts_order = "ymd";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%\{ce_year\}\.\ \%B\ \%\{day\}\." }
sub long_date_format               { "\%\{ce_year\}\.\ \%B\ \%\{day\}\." }
sub medium_date_format             { "\%\{ce_year\}\.\%m\.\%d\." }
sub short_date_format              { "\%\{ce_year\}\.\%m\.\%d\." }
sub full_time_format               { "\%\{hour\}\:\%M\:\%S\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%\{hour\}\:\%M\:\%S\ \%\{time_zone_long_name\}" }
sub medium_time_format             { "\%\{hour\}\:\%M\:\%S" }
sub short_time_format              { "\%\{hour\}\:\%M" }
sub date_parts_order               { $date_parts_order }



1;

