###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file mt.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::mt;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::mt::ISA = qw(DateTime::Locale::root);

my @day_names = (
"It\-Tnejn",
"It\-Tlieta",
"L\-Erbgħa",
"Il\-Ħamis",
"Il\-Ġimgħa",
"Is\-Sibt",
"Il\-Ħadd",
);

my @day_abbreviations = (
"Tne",
"Tli",
"Erb",
"Ħam",
"Ġim",
"Sib",
"Ħad",
);

my @month_names = (
"Jannar",
"Frar",
"Marzu",
"April",
"Mejju",
"Ġunju",
"Lulju",
"Awissu",
"Settembru",
"Ottubru",
"Novembru",
"Diċembru",
);

my @month_abbreviations = (
"Jan",
"Fra",
"Mar",
"Apr",
"Mej",
"Ġun",
"Lul",
"Awi",
"Set",
"Ott",
"Nov",
"Diċ",
);

my @eras = (
"QK",
"WK",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%\{day\}\ ta\'\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\ ta\'\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\ \%b\ \%\{ce_year\}" }
sub short_date_format              { "\%d\/\%m\/\%\{ce_year\}" }
sub date_parts_order               { $date_parts_order }



1;

