###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ml.xml.
# The source file version number was 1.0, generated on
# 2004-09-20.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ml;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::ml::ISA = qw(DateTime::Locale::root);

my @day_names = (
"തിങ്കള്അ",
"ചൊവ്വ",
"ബുനഭ്അ",
"വ്യാഴം",
"വെള്ളി",
"ശനി",
"ഞായറ്അ",
);

my @day_abbreviations = (
"തി",
"ചൊ",
"ബു",
"വ്യ",
"വെ",
"ശ",
"ഞാ",
);

my @month_names = (
"ജനുവരി",
"ഫിബ്റവരി",
"മാറ്അച്അച്",
"ഏപ്റില്അ",
"മെയ്",
"ജൂണ്അ",
"ജൂൈല",
"ആഗസ്ത്അ",
"സെപ്തംബറ്അ",
"ഒക്ടൈബറ്അ",
"നവംബറ്അ",
"ഡിസംബറ്അ",
);

my @month_abbreviations = (
"ജനു",
"ഫിബ്",
"മാറ്അ",
"ഏപ്റില്അ",
"മെയ്",
"ജൂണ്അ",
"ജൂൈല",
"ആഗ",
"സെപ്തം",
"ഒക്ട",
"നവം",
"ഡിസം",
);

my @am_pms = (
"രാവിലെ",
"വൈകു",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }



1;

