###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file it.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:56:15Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::it;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::it::ISA = qw(DateTime::Locale::root);

my @day_names = (
"lunedì",
"martedì",
"mercoledì",
"giovedì",
"venerdì",
"sabato",
"domenica",
);

my @day_abbreviations = (
"lun",
"mar",
"mer",
"gio",
"ven",
"sab",
"dom",
);

my @day_narrows = (
"L",
"M",
"M",
"G",
"V",
"S",
"D",
);

my @month_names = (
"gennaio",
"febbraio",
"marzo",
"aprile",
"maggio",
"giugno",
"luglio",
"agosto",
"settembre",
"ottobre",
"novembre",
"dicembre",
);

my @month_abbreviations = (
"gen",
"feb",
"mar",
"apr",
"mag",
"giu",
"lug",
"ago",
"set",
"ott",
"nov",
"dic",
);

my @month_narrows = (
"G",
"F",
"M",
"A",
"M",
"G",
"L",
"A",
"S",
"O",
"N",
"D",
);

my @am_pms = (
"m\.",
"p\.",
);

my @eras = (
"aC",
"dC",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A\ \%\{day\}\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%d\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\/\%b\/\%y" }
sub short_date_format              { "\%d\/\%m\/\%y" }
sub date_parts_order               { $date_parts_order }



1;

