###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file es.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:56:06Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::es;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::es::ISA = qw(DateTime::Locale::root);

my @day_names = (
"lunes",
"martes",
"miércoles",
"jueves",
"viernes",
"sábado",
"domingo",
);

my @day_abbreviations = (
"lun",
"mar",
"mié",
"jue",
"vie",
"sáb",
"dom",
);

my @day_narrows = (
"L",
"M",
"M",
"J",
"V",
"S",
"D",
);

my @month_names = (
"enero",
"febrero",
"marzo",
"abril",
"mayo",
"junio",
"julio",
"agosto",
"septiembre",
"octubre",
"noviembre",
"diciembre",
);

my @month_abbreviations = (
"ene",
"feb",
"mar",
"abr",
"may",
"jun",
"jul",
"ago",
"sep",
"oct",
"nov",
"dic",
);

my @month_narrows = (
"E",
"F",
"M",
"A",
"M",
"J",
"J",
"A",
"S",
"O",
"N",
"D",
);

my @eras = (
"a\.C\.",
"d\.C\.",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub eras                           { \@eras }
sub full_date_format               { "\%A\ \%\{day\}\ de\ \%B\ de\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\ de\ \%B\ de\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\-\%b\-\%y" }
sub short_date_format              { "\%\{day\}\/\%m\/\%y" }
sub full_time_format               { "\%HH\%M\'\%S\"\ \%\{time_zone_long_name\}" }
sub date_parts_order               { $date_parts_order }



1;

