###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file fa.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fa;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::fa::ISA = qw(DateTime::Locale::root);

my @day_names = (
"دوشنبه",
"سه‌شنبه",
"چهارشنبه",
"پنج‌شنبه",
"جمعه",
"شنبه",
"یک‌شنبه",
);

my @day_abbreviations = (
"د\.",
"س\.",
"چ\.",
"پ\.",
"ج\.",
"ش\.",
"ی\.",
);

my @month_names = (
"ژانویه",
"فوریه",
"مارس",
"آوریل",
"مه",
"ژوئن",
"ژوئیه",
"اوت",
"سپتامبر",
"اکتبر",
"نوامبر",
"دسامبر",
);

my @month_abbreviations = (
"ژان",
"فور",
"مار",
"آور",
"مـه",
"ژون",
"ژوی",
"اوت",
"سپت",
"اکت",
"نوا",
"دسا",
);

my @am_pms = (
"ق\.ظ\.",
"ب\.ظ\.",
);

my @eras = (
"ق\.م\.",
"م\.",
);

my $date_parts_order = "ymd";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A،\ \%\{day\}\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{ce_year\}\/\%m\/\%\{day\}" }
sub short_date_format              { "\%\{ce_year\}\/\%m\/\%\{day\}" }
sub full_time_format               { "\%H\:\%M\:\%S\ \(\%\{time_zone_long_name\}\)" }
sub long_time_format               { "\%H\:\%M\:\%S\ \(\%\{time_zone_long_name\}\)" }
sub date_parts_order               { $date_parts_order }



1;

