###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file sv.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:58:46Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sv;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::sv::ISA = qw(DateTime::Locale::root);

my @day_names = (
"måndag",
"tisdag",
"onsdag",
"torsdag",
"fredag",
"lördag",
"söndag",
);

my @day_abbreviations = (
"må",
"ti",
"on",
"to",
"fr",
"lö",
"sö",
);

my @day_narrows = (
"M",
"T",
"O",
"T",
"F",
"L",
"S",
);

my @month_names = (
"januari",
"februari",
"mars",
"april",
"maj",
"juni",
"juli",
"augusti",
"september",
"oktober",
"november",
"december",
);

my @month_abbreviations = (
"jan",
"feb",
"mar",
"apr",
"maj",
"jun",
"jul",
"aug",
"sep",
"okt",
"nov",
"dec",
);

my @month_narrows = (
"J",
"F",
"M",
"A",
"M",
"J",
"J",
"A",
"S",
"O",
"N",
"D",
);

my @am_pms = (
"f\.m\.",
"e\.m\.",
);

my @eras = (
"f\.Kr\.",
"e\.Kr\.",
);

my $date_parts_order = "ymd";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "den\ \%\{day\}\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "den\ \%\{day\}\ \%b\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{ce_year\}\-\%m\-\%d" }
sub short_date_format              { "\%\{ce_year\}\-\%m\-\%d" }
sub full_time_format               { "kl\.\ \%H\.\%M\.\%S\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%H\.\%M\.\%S\ \%\{time_zone_long_name\}" }
sub medium_time_format             { "\%H\.\%M\.\%S" }
sub short_time_format              { "\%H\.\%M" }
sub date_parts_order               { $date_parts_order }



1;

