###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file sr.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sr;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::sr::ISA = qw(DateTime::Locale::root);

my @day_names = (
"понедељак",
"уторак",
"среда",
"четвртак",
"петак",
"субота",
"недеља",
);

my @day_abbreviations = (
"пон",
"уто",
"сре",
"чет",
"пет",
"суб",
"нед",
);

my @day_narrows = (
"п",
"у",
"с",
"ч",
"п",
"с",
"н",
);

my @month_names = (
"јануар",
"фебруар",
"март",
"април",
"мај",
"јун",
"јул",
"август",
"септембар",
"октобар",
"новембар",
"децембар",
);

my @month_abbreviations = (
"јан",
"феб",
"мар",
"апр",
"мај",
"јун",
"јул",
"авг",
"сеп",
"окт",
"нов",
"дец",
);

my @month_narrows = (
"ј",
"ф",
"м",
"а",
"м",
"ј",
"ј",
"а",
"с",
"о",
"н",
"д",
);

my @eras = (
"п\.\ н\.\ е\.",
"н\.\ е",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%d\.\%B\.\%\{ce_year\}\." }
sub long_date_format               { "\%d\.\%m\.\%\{ce_year\}\." }
sub medium_date_format             { "\%d\.\%m\.\%\{ce_year\}\." }
sub short_date_format              { "\%\{day\}\.\%\{month\}\.\%y\." }
sub full_time_format               { "\%H\.\%M\.\%S\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%H\.\%M\.\%S\ \%\{time_zone_long_name\}" }
sub medium_time_format             { "\%H\.\%M\.\%S" }
sub short_time_format              { "\%H\.\%M" }
sub date_parts_order               { $date_parts_order }



1;

