###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file as.xml.
# The source file version number was 0.3, generated on
# 2004-09-13.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::as;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::as::ISA = qw(DateTime::Locale::root);

my @day_names = (
"সোমবাৰ",
"মঙ্গলবাৰ",
"বুধবাৰ",
"বৃহষ্পতিবাৰ",
"শুক্ৰবাৰ",
"শনিবাৰ",
"ৰবিবাৰ",
);

my @day_abbreviations = (
"সোম",
"মঙ্গল",
"বুধ",
"বৃহষ্পতি",
"শুক্ৰ",
"শনি",
"ৰবি",
);

my @month_names = (
"জানুয়াৰী",
"ফেব্ৰুয়াৰী",
"মাৰ্চ",
"এপ্ৰিল",
"মে",
"জুন",
"জুলাই",
"আগষ্ট",
"সেপ্টেম্বৰ",
"অক্টোবৰ",
"নভেম্বৰ",
"ডিসেম্বৰ",
);

my @month_abbreviations = (
"জানু",
"ফেব্ৰু",
"মাৰ্চ",
"এপ্ৰিল",
"মে",
"জুন",
"জুলাই",
"আগ",
"সেপ্ট",
"অক্টো",
"নভে",
"ডিসে",
);

my @am_pms = (
"পূৰ্বা",
"অপ",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }



1;

