###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file iu.xml.
# The source file version number was 1.2, generated on
# 2004-06-04.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::iu;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::iu::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ᓇᒡᒐᔾᔭᐅ",
"ᓇᒡᒐᔾᔭᐅᓕᖅᑭ",
"ᐱᖓᑦᓯᖅ",
"ᓯᑕᒻᒥᖅ",
"ᑕᓪᓕᕐᒥᖅ",
"ᓈᑦᓰᖑᔭᓕᖅᕿ",
"ᓈᑦᓰᖑᔭ",
);

my @day_abbreviations = (
"ᓇᒡᒐᔾᔭᐅ",
"ᓇᒡᒐᔾᔭᐅᓕᖅᑭ",
"ᐱᖓᑦᓯᖅ",
"ᓯᑕᒻᒥᖅ",
"ᑕᓪᓕᕐᒥᖅ",
"ᓈᑦᓰᖑᔭᓕᖅᕿ",
"ᓈᑦᓰᖑᔭ",
);

my @month_names = (
"ᔭᓐᓄᐊᓕ",
"ᕕᕝᕗᐊᓕ",
"ᒫᑦᓯ",
"ᐊᐃᑉᐳᓗ",
"ᒪᐃ",
"ᔫᓂ",
"ᔪᓚᐃ",
"ᐊᐅᒡᒍᓯ",
"ᓰᑦᑏᕝᕙ",
"ᐆᑦᑑᕝᕙ",
"ᓅᕙᐃᕝᕙ",
"ᑏᓰᕝᕙ",
);

my @month_abbreviations = (
"ᔭᓐᓄᐊᓕ",
"ᕕᕝᕗᐊᓕ",
"ᒫᑦᓯ",
"ᐊᐃᑉᐳᓗ",
"ᒪᐃ",
"ᔫᓂ",
"ᔪᓚᐃ",
"ᐊᐅᒡᒍᓯ",
"ᓰᑦᑏᕝᕙ",
"ᐆᑦᑑᕝᕙ",
"ᓅᕙᐃᕝᕙ",
"ᑏᓰᕝᕙ",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }



1;

