###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file tr.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:58:48Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::tr;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::tr::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Pazartesi",
"Salı",
"Çarşamba",
"Perşembe",
"Cuma",
"Cumartesi",
"Pazar",
);

my @day_abbreviations = (
"Pzt",
"Sal",
"Çar",
"Per",
"Cum",
"Cmt",
"Paz",
);

my @day_narrows = (
"P",
"S",
"Ç",
"P",
"C",
"C",
"P",
);

my @month_names = (
"Ocak",
"Şubat",
"Mart",
"Nisan",
"Mayıs",
"Haziran",
"Temmuz",
"Ağustos",
"Eylül",
"Ekim",
"Kasım",
"Aralık",
);

my @month_abbreviations = (
"Oca",
"Şub",
"Mar",
"Nis",
"May",
"Haz",
"Tem",
"Ağu",
"Eyl",
"Eki",
"Kas",
"Ara",
);

my @month_narrows = (
"O",
"Ş",
"M",
"N",
"M",
"H",
"T",
"A",
"E",
"E",
"K",
"A",
);

my @eras = (
"MÖ",
"MS",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub eras                           { \@eras }
sub full_date_format               { "\%d\ \%B\ \%\{ce_year\}\ \%A" }
sub long_date_format               { "\%d\ \%B\ \%\{ce_year\}\ \%A" }
sub medium_date_format             { "\%d\.\%b\.\%\{ce_year\}" }
sub short_date_format              { "\%d\.\%m\.\%\{ce_year\}" }
sub date_parts_order               { $date_parts_order }



1;

