###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file hy.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::hy;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::hy::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Երկուշաբթի",
"Երեքշաբթի",
"Չորեքշաբթի",
"Հինգշաբթի",
"Ուրբաթ",
"Շաբաթ",
"Կիրակի",
);

my @day_abbreviations = (
"Երկ",
"Երք",
"Չոր",
"Հնգ",
"Ուր",
"Շաբ",
"Կիր",
);

my @month_names = (
"Յունուար",
"Փետրուար",
"Մարտ",
"Ապրիլ",
"Մայիս",
"Յունիս",
"Յուլիս",
"Օգոստոս",
"Սեպտեմբեր",
"Հոկտեմբեր",
"Նոյեմբեր",
"Դեկտեմբեր",
);

my @month_abbreviations = (
"Յնր",
"Փտր",
"Մրտ",
"Ապր",
"Մյս",
"Յնս",
"Յլս",
"Օգս",
"Սեպ",
"Հոկ",
"Նոյ",
"Դեկ",
);

my @am_pms = (
"Առ․",
"Եր․",
);

my @eras = (
"Յ․Տ․",
"Ն․Ք․",
);

my $date_parts_order = "mdy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%B\ \%\{day\}\,\ \%\{ce_year\}" }
sub long_date_format               { "\%B\ \%d\,\ \%\{ce_year\}" }
sub medium_date_format             { "\%b\ \%\{day\}\,\ \%\{ce_year\}" }
sub short_date_format              { "\%m\/\%d\/\%y" }
sub date_parts_order               { $date_parts_order }



1;

