###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file gu.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::gu;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::gu::ISA = qw(DateTime::Locale::root);

my @day_names = (
"સોમવાર",
"મંગળવાર",
"બુધવાર",
"ગુરુવાર",
"શુક્રવાર",
"શનિવાર",
"રવિવાર",
);

my @day_abbreviations = (
"સોમ",
"મંગળ",
"બુધ",
"ગુરુ",
"શુક્ર",
"શનિ",
"રવિ",
);

my @month_names = (
"જાન્યુઆરી",
"ફેબ્રુઆરી",
"માર્ચ",
"એપ્રિલ",
"મે",
"જૂન",
"જુલાઈ",
"ઑગસ્ટ",
"સપ્ટેમ્બર",
"ઑક્ટ્બર",
"નવેમ્બર",
"ડિસેમ્બર",
);

my @month_abbreviations = (
"જાન્યુ",
"ફેબ્રુ",
"માર્ચ",
"એપ્રિલ",
"મે",
"જૂન",
"જુલાઈ",
"ઑગસ્ટ",
"સપ્ટે",
"ઑક્ટો",
"નવે",
"ડિસે",
);

my @am_pms = (
"પૂર્વ મધ્યાહ્ન",
"ઉત્તર મધ્યાહ્ન",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }



1;

