###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file wal.xml.
# The source file version number was 1.2, generated on
# 2004-06-04.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::wal;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::wal::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ሳይኖ",
"ማቆሳኛ",
"አሩዋ",
"ሃሙሳ",
"አርባ",
"ቄራ",
"ወጋ",
);

my @day_abbreviations = (
"ሳይኖ",
"ማቆሳ",
"አሩዋ",
"ሃሙሳ",
"አርባ",
"ቄራ",
"ወጋ",
);

my @am_pms = (
"ማለዶ",
"ቃማ",
);

my @eras = (
"አዳ\ ዎዴ",
"ግሮተታ\ ላይታ",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }



1;

