###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ar.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:55:56Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ar;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::ar::ISA = qw(DateTime::Locale::root);

my @day_names = (
"الاثنين",
"الثلاثاء",
"الأربعاء",
"الخميس",
"الجمعة",
"السبت",
"الأحد",
);

my @day_abbreviations = (
"ن",
"ث",
"ر",
"خ",
"ج",
"س",
"ح",
);

my @day_narrows = (
"ن",
"ث",
"ر",
"خ",
"ج",
"س",
"ح",
);

my @month_names = (
"يناير",
"فبراير",
"مارس",
"أبريل",
"مايو",
"يونيو",
"يوليو",
"أغسطس",
"سبتمبر",
"أكتوبر",
"نوفمبر",
"ديسمبر",
);

my @month_abbreviations = (
"يناير",
"فبراير",
"مارس",
"أبريل",
"مايو",
"يونيو",
"يوليو",
"أغسطس",
"سبتمبر",
"أكتوبر",
"نوفمبر",
"ديسمبر",
);

my @month_narrows = (
"ي",
"ف",
"م",
"آ",
"و",
"ن",
"ل",
"غ",
"س",
"ك",
"ب",
"د",
);

my @am_pms = (
"ص",
"م",
);

my @eras = (
"ق\.م",
"م",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%\{day\}\ \%B\,\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\ \%B\,\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\/\%m\/\%\{ce_year\}" }
sub short_date_format              { "\%\{day\}\/\%\{month\}\/\%\{ce_year\}" }
sub full_time_format               { "\%\{time_zone_long_name\}\ \%\{hour_12\}\:\%M\:\%S\ \%p" }
sub long_time_format               { "\%\{hour_12\}\:\%M\:\%S\ \%p" }
sub medium_time_format             { "\%\{hour_12\}\:\%M\:\%S\ \%p" }
sub short_time_format              { "\%\{hour_12\}\:\%M\ \%p" }
sub date_parts_order               { $date_parts_order }



1;

