###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file gez.xml.
# The source file version number was 1.2, generated on
# 2004-06-04.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::gez;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::gez::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ሰኑይ",
"ሠሉስ",
"ራብዕ",
"ሐሙስ",
"ዓርበ",
"ቀዳሚት",
"እኁድ",
);

my @day_abbreviations = (
"ሰኑይ",
"ሠሉስ",
"ራብዕ",
"ሐሙስ",
"ዓርበ",
"ቀዳሚ",
"እኁድ",
);

my @month_names = (
"ጠሐረ",
"ከተተ",
"መገበ",
"አኀዘ",
"ግንባት",
"ሠንየ",
"ሐመለ",
"ነሐሰ",
"ከረመ",
"ጠቀመ",
"ኀደረ",
"ኀሠሠ",
);

my @month_abbreviations = (
"ጠሐረ",
"ከተተ",
"መገበ",
"አኀዘ",
"ግንባ",
"ሠንየ",
"ሐመለ",
"ነሐሰ",
"ከረመ",
"ጠቀመ",
"ኀደረ",
"ኀሠሠ",
);

my @am_pms = (
"ጽባሕ",
"ምሴት",
);

my @eras = (
"ዓ\/ዓ",
"ዓ\/ም",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }



1;

