###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file pt.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:58:41Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::pt;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::pt::ISA = qw(DateTime::Locale::root);

my @day_names = (
"segunda\-feira",
"terça\-feira",
"quarta\-feira",
"quinta\-feira",
"sexta\-feira",
"sábado",
"domingo",
);

my @day_abbreviations = (
"seg",
"ter",
"qua",
"qui",
"sex",
"sáb",
"dom",
);

my @day_narrows = (
"S",
"T",
"Q",
"Q",
"S",
"S",
"D",
);

my @month_names = (
"janeiro",
"fevereiro",
"março",
"abril",
"maio",
"junho",
"julho",
"agosto",
"setembro",
"outubro",
"novembro",
"dezembro",
);

my @month_abbreviations = (
"jan",
"fev",
"mar",
"abr",
"mai",
"jun",
"jul",
"ago",
"set",
"out",
"nov",
"dez",
);

my @month_narrows = (
"J",
"F",
"M",
"A",
"M",
"J",
"J",
"A",
"S",
"O",
"N",
"D",
);

my @eras = (
"a\.C\.",
"d\.C\.",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%\{day\}\ de\ \%B\ de\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\ de\ \%B\ de\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{day\}\/\%b\/\%\{ce_year\}" }
sub short_date_format              { "\%d\-\%m\-\%\{ce_year\}" }
sub full_time_format               { "\%HH\%Mm\%Ss\ \%\{time_zone_long_name\}" }
sub date_parts_order               { $date_parts_order }



1;

