###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file zh.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::zh;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::zh::ISA = qw(DateTime::Locale::root);

my @day_names = (
"星期一",
"星期二",
"星期三",
"星期四",
"星期五",
"星期六",
"星期日",
);

my @day_abbreviations = (
"一",
"二",
"三",
"四",
"五",
"六",
"日",
);

my @day_narrows = (
"一",
"二",
"三",
"四",
"五",
"六",
"日",
);

my @month_names = (
"一月",
"二月",
"三月",
"四月",
"五月",
"六月",
"七月",
"八月",
"九月",
"十月",
"十一月",
"十二月",
);

my @month_abbreviations = (
"一月",
"二月",
"三月",
"四月",
"五月",
"六月",
"七月",
"八月",
"九月",
"十月",
"十一月",
"十二月",
);

my @month_narrows = (
"1月",
"2月",
"3月",
"4月",
"5月",
"6月",
"7月",
"8月",
"9月",
"10月",
"11月",
"12月",
);

my @am_pms = (
"上午",
"下午",
);

my @eras = (
"公元前",
"公元",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }



1;

