###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file pl.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:58:39Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::pl;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::pl::ISA = qw(DateTime::Locale::root);

my @day_names = (
"poniedziałek",
"wtorek",
"środa",
"czwartek",
"piątek",
"sobota",
"niedziela",
);

my @day_abbreviations = (
"Pn",
"Wt",
"Śr",
"Cz",
"Pt",
"So",
"N",
);

my @day_narrows = (
"P",
"W",
"Ś",
"C",
"P",
"S",
"N",
);

my @month_names = (
"stycznia",
"lutego",
"marca",
"kwietnia",
"maja",
"czerwca",
"lipca",
"sierpnia",
"września",
"października",
"listopada",
"grudnia",
);

my @month_abbreviations = (
"st",
"lut",
"mrz",
"kw",
"maj",
"cz",
"lip",
"sier",
"wrz",
"paź",
"lis",
"gr",
);

my @month_narrows = (
"s",
"l",
"m",
"k",
"m",
"c",
"l",
"s",
"w",
"p",
"l",
"g",
);

my @eras = (
"p\.n\.e\.",
"n\.e\.",
);

my $date_parts_order = "ymd";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%\{day\}\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{ce_year\}\-\%m\-\%d" }
sub short_date_format              { "\%y\-\%m\-\%d" }
sub date_parts_order               { $date_parts_order }



1;

