###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file fo.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fo;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::fo::ISA = qw(DateTime::Locale::root);

my @day_names = (
"mánadagur",
"týsdagur",
"mikudagur",
"hósdagur",
"fríggjadagur",
"leygardagur",
"sunnudagur",
);

my @day_abbreviations = (
"mán",
"týs",
"mik",
"hós",
"frí",
"ley",
"sun",
);

my @month_names = (
"januar",
"februar",
"mars",
"apríl",
"mai",
"juni",
"juli",
"august",
"september",
"oktober",
"november",
"desember",
);

my @month_abbreviations = (
"jan",
"feb",
"mar",
"apr",
"mai",
"jun",
"jul",
"aug",
"sep",
"okt",
"nov",
"des",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub full_date_format               { "\%A\ \%d\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\.\ \%b\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\-\%m\-\%\{ce_year\}" }
sub short_date_format              { "\%d\-\%m\-\%y" }
sub date_parts_order               { $date_parts_order }



1;

