###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file cy.xml.
# The source file version number was 1.3, generated on
# 2005-02-03T21:09:39Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::cy;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::cy::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Dydd\ Llun",
"Dydd\ Mawrth",
"Dydd\ Mercher",
"Dydd\ Iau",
"Dydd\ Gwener",
"Dydd\ Sadwrn",
"Dydd\ Sul",
);

my @day_abbreviations = (
"Llun",
"Maw",
"Mer",
"Iau",
"Gwen",
"Sad",
"Sul",
);

my @day_narrows = (
"L",
"M",
"M",
"I",
"G",
"S",
"S",
);

my @month_names = (
"Ionawr",
"Chwefror",
"Mawrth",
"Ebrill",
"Mai",
"Mehefin",
"Gorffenaf",
"Awst",
"Medi",
"Hydref",
"Tachwedd",
"Rhagfyr",
);

my @month_abbreviations = (
"Ion",
"Chwef",
"Mawrth",
"Ebrill",
"Mai",
"Meh",
"Gorff",
"Awst",
"Medi",
"Hyd",
"Tach",
"Rhag",
);

my @month_narrows = (
"I",
"C",
"M",
"E",
"M",
"M",
"G",
"A",
"M",
"H",
"T",
"R",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }



1;

