###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file cs.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:55:58Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::cs;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::cs::ISA = qw(DateTime::Locale::root);

my @day_names = (
"pondělí",
"úterý",
"středa",
"čtvrtek",
"pátek",
"sobota",
"neděle",
);

my @day_abbreviations = (
"po",
"út",
"st",
"čt",
"pá",
"so",
"ne",
);

my @month_names = (
"ledna",
"února",
"března",
"dubna",
"května",
"června",
"července",
"srpna",
"září",
"října",
"listopadu",
"prosince",
);

my @month_abbreviations = (
"1\.",
"2\.",
"3\.",
"4\.",
"5\.",
"6\.",
"7\.",
"8\.",
"9\.",
"10\.",
"11\.",
"12\.",
);

my @month_narrows = (
"l",
"ú",
"b",
"d",
"k",
"č",
"č",
"s",
"z",
"ř",
"l",
"p",
);

my @am_pms = (
"dop\.",
"odp\.",
);

my @eras = (
"př\.Kr\.",
"po\ Kr\.",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%\{day\}\.\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\.\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{day\}\.\%\{month\}\.\%\{ce_year\}" }
sub short_date_format              { "\%\{day\}\.\%\{month\}\.\%y" }
sub full_time_format               { "\%\{hour\}\:\%M\:\%S\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%\{hour\}\:\%M\:\%S\ \%\{time_zone_long_name\}" }
sub medium_time_format             { "\%\{hour\}\:\%M\:\%S" }
sub short_time_format              { "\%\{hour\}\:\%M" }
sub date_parts_order               { $date_parts_order }



1;

