###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ti_ER.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ti_ER;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::ti;

@DateTime::Locale::ti_ER::ISA = qw(DateTime::Locale::ti);

my @month_names = (
"ጥሪ",
"ለካቲት",
"መጋቢት",
"ሚያዝያ",
"ግንቦት",
"ሰነ",
"ሓምለ",
"ነሓሰ",
"መስከረም",
"ጥቅምቲ",
"ሕዳር",
"ታሕሳስ",
);

my @month_abbreviations = (
"ጥሪ",
"ለካቲ",
"መጋቢ",
"ሚያዝ",
"ግንቦ",
"ሰነ",
"ሓምለ",
"ነሓሰ",
"መስከ",
"ጥቅም",
"ሕዳር",
"ታሕሳ",
);

my $date_parts_order = "dmy";


sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub full_date_format               { "\%A፡\ \%d\ \%B\ መዓልቲ\ \%\{ce_year\}\ \%\{era\}" }
sub long_date_format               { "\%d\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\-\%b\-\%y" }
sub short_date_format              { "\%d\/\%m\/\%y" }
sub full_time_format               { "\%\{hour_12\}\:\%M\:\%S\ \%p" }
sub long_time_format               { "\%\{hour_12\}\:\%M\:\%S\ \%p" }
sub medium_time_format             { "\%\{hour_12\}\:\%M\:\%S\ \%p" }
sub short_time_format              { "\%\{hour_12\}\:\%M\ \%p" }
sub date_parts_order               { $date_parts_order }



1;

