###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file sr_Latn.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sr_Latn;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::sr;

@DateTime::Locale::sr_Latn::ISA = qw(DateTime::Locale::sr);

my @day_names = (
"ponedeljak",
"utorak",
"sreda",
"četvrtak",
"petak",
"subota",
"nedelja",
);

my @day_abbreviations = (
"pon",
"uto",
"sre",
"čet",
"pet",
"sub",
"ned",
);

my @day_narrows = (
"p",
"u",
"s",
"č",
"p",
"s",
"n",
);

my @month_names = (
"januar",
"februar",
"mart",
"april",
"maj",
"jun",
"jul",
"avgust",
"septembar",
"oktobar",
"novembar",
"decembar",
);

my @month_abbreviations = (
"jan",
"feb",
"mar",
"apr",
"maj",
"jun",
"jul",
"avg",
"sep",
"okt",
"nov",
"dec",
);

my @month_narrows = (
"j",
"f",
"m",
"a",
"m",
"j",
"j",
"a",
"s",
"o",
"n",
"d",
);

my @eras = (
"p\.\ n\.\ e\.",
"n\.\ e\.",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%d\.\ \%B\ \%\{ce_year\}\." }
sub long_date_format               { "\%A\,\ \%\{day\}\.\%m\.\%\{ce_year\}\." }



1;

