###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ta.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ta;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::ta::ISA = qw(DateTime::Locale::root);

my @day_names = (
"திங்கள்",
"செவ்வாய்",
"புதன்",
"வியாழன்",
"வெள்ளி",
"சனி",
"ஞாயிறு",
);

my @day_abbreviations = (
"தி",
"செ",
"பு",
"வி",
"வெ",
"ச",
"ஞா",
);

my @month_names = (
"ஜனவரி",
"பிப்ரவரி",
"மார்ச்",
"ஏப்ரல்",
"மே",
"ஜூன்",
"ஜூலை",
"ஆகஸ்ட்",
"செப்டம்பர்",
"அக்டோபர்",
"நவம்பர்",
"டிசம்பர்",
);

my @month_abbreviations = (
"ஜன\.",
"பிப்\.",
"மார்\.",
"ஏப்\.",
"மே",
"ஜூன்",
"ஜூலை",
"ஆக\.",
"செப்\.",
"அக்\.",
"நவ\.",
"டிச\.",
);

my @am_pms = (
"காலை",
"மாலை",
);

my @eras = (
"கிமு",
"கிபி",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }



1;

