###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file vi.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::vi;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::vi::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Thứ\ hai",
"Thứ\ ba",
"Thứ\ tư",
"Thứ\ năm",
"Thứ\ sáu",
"Thứ\ bảy",
"Chủ\ nhật",
);

my @day_abbreviations = (
"Th\ 2",
"Th\ 3",
"Th\ 4",
"Th\ 5",
"Th\ 6",
"Th\ 7",
"CN",
);

my @month_names = (
"tháng\ một",
"tháng\ hai",
"tháng\ ba",
"tháng\ tư",
"tháng\ năm",
"tháng\ sáu",
"tháng\ bảy",
"tháng\ tám",
"tháng\ chín",
"tháng\ mười",
"tháng\ mười\ một",
"tháng\ mười\ hai",
);

my @month_abbreviations = (
"thg\ 1",
"thg\ 2",
"thg\ 3",
"thg\ 4",
"thg\ 5",
"thg\ 6",
"thg\ 7",
"thg\ 8",
"thg\ 9",
"thg\ 10",
"thg\ 11",
"thg\ 12",
);

my @am_pms = (
"SA",
"CH",
);

my @eras = (
"tr\.\ CN",
"sau\ CN",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ ngày\ \%d\ \%B\ năm\ \%\{ce_year\}" }
sub long_date_format               { "Ngày\ \%d\ tháng\ \%\{month\}\ năm\ \%\{ce_year\}" }
sub medium_date_format             { "\%d\-\%m\-\%\{ce_year\}" }
sub short_date_format              { "\%d\/\%m\/\%\{ce_year\}" }
sub date_parts_order               { $date_parts_order }



1;

