###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file fi.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:56:08Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::fi;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::fi::ISA = qw(DateTime::Locale::root);

my @day_names = (
"maanantai",
"tiistai",
"keskiviikko",
"torstai",
"perjantai",
"lauantai",
"sunnuntai",
);

my @day_abbreviations = (
"ma",
"ti",
"ke",
"to",
"pe",
"la",
"su",
);

my @day_narrows = (
"M",
"T",
"K",
"T",
"P",
"L",
"S",
);

my @month_names = (
"tammikuu",
"helmikuu",
"maaliskuu",
"huhtikuu",
"toukokuu",
"kesäkuu",
"heinäkuu",
"elokuu",
"syyskuu",
"lokakuu",
"marraskuu",
"joulukuu",
);

my @month_abbreviations = (
"tammi",
"helmi",
"maalis",
"huhti",
"touko",
"kesä",
"heinä",
"elo",
"syys",
"loka",
"marras",
"joulu",
);

my @month_narrows = (
"T",
"H",
"M",
"H",
"T",
"K",
"H",
"E",
"S",
"L",
"M",
"J",
);

my @am_pms = (
"ap\.",
"ip\.",
);

my @eras = (
"eaa\.",
"jaa\.",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%\{day\}\.\ \%Bta\ \%\{ce_year\}" }
sub long_date_format               { "\%\{day\}\.\ \%Bta\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{day\}\.\%\{month\}\.\%\{ce_year\}" }
sub short_date_format              { "\%\{day\}\.\%\{month\}\.\%\{ce_year\}" }
sub full_time_format               { "\%\{hour\}\.\%M\.\%S\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%\{hour\}\.\%M\.\%S\ \%\{time_zone_long_name\}" }
sub medium_time_format             { "\%\{hour\}\.\%M\.\%S" }
sub short_time_format              { "\%\{hour\}\.\%M" }
sub date_parts_order               { $date_parts_order }



1;

