###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file az.xml.
# The source file version number was 1.3, generated on
# 2005-01-13.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::az;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::az::ISA = qw(DateTime::Locale::root);

my @day_names = (
"bazar\ ertəsi",
"çərşənbə\ axşam",
"çərşənbə",
"cümə\ axşamı",
"cümə",
"şənbə",
"bazar",
);

my @day_abbreviations = (
"B\.e\.",
"Ç\.a\.",
"Ç\.",
"C\.a\.",
"C\.",
"Ş\.",
"B\.",
);

my @month_names = (
"Yanvar",
"Fevral",
"Mart",
"Aprel",
"May",
"İyun",
"İyul",
"Avqust",
"Sentyabr",
"Oktyabr",
"Noyabr",
"Dekabr",
);

my @month_abbreviations = (
"yan",
"fev",
"mar",
"apr",
"may",
"iyn",
"iyl",
"avq",
"sen",
"okt",
"noy",
"dek",
);

my @am_pms = (
"AM",
"PM",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }



1;

