###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file km.xml.
# The source file version number was 1.2, generated on
# 2004-07-31.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::km;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::km::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ថ្ងៃ​ច័ន្ទ",
"ថ្ងៃ​អង្គារ",
"ថ្ងៃ​ពុធ",
"ថ្ងៃ​ព្រហស្បតិ៍",
"ថ្ងៃ​សុក្រ",
"ថ្ងៃ​សៅរ៍",
"ថ្ងៃ​អាទិត្យ",
);

my @day_abbreviations = (
"ច",
"អ",
"ពុ",
"ព្រ",
"សុ",
"ស",
"អា",
);

my @month_names = (
"មករា",
"កុម្ភៈ",
"មិនា",
"មេសា",
"ឧសភា",
"មិថុនា",
"កក្កដា",
"សីហា",
"កញ្ញា",
"តុលា",
"វិច្ឆិកា",
"ធ្នូ",
);

my @month_abbreviations = (
"១",
"២",
"៣",
"៤",
"៥",
"៦",
"៧",
"៨",
"៩",
"១០",
"១១",
"១២",
);

my @am_pms = (
"ព្រឹក",
"ល្ងាច",
);

my $date_parts_order = "dmy";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub full_date_format               { "\%A\ ថ្ងៃ\ \%\{day\}\ ខែ\ \%B\ ឆ្នាំ\ \ \%\{ce_year\}" }
sub long_date_format               { "\%A\ ថ្ងៃ\ \%\{day\}\ ខែ\ \%B\ ឆ្នាំ\ \ \%\{ce_year\}" }
sub medium_date_format             { "\%\{day\}\ \%B\ \%\{ce_year\}" }
sub short_date_format              { "\%\{day\}\/\%\{month\}\/\%\{ce_year\}" }
sub full_time_format               { "\%\{hour\}\ ម៉ោង\ \%\{minute\}\ នាទី\ \%S\ វិនាទី​\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%\{hour\}\ ម៉ោង\ \%\{minute\}\ នាទី\ \%S\ វិនាទី​" }
sub medium_time_format             { "\%\{hour\}\:\%M\:\%S" }
sub short_time_format              { "\%\{hour\}\:\%M" }
sub date_parts_order               { $date_parts_order }



1;

