###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ja.xml.
# The source file version number was 1.3, generated on
# 2005-01-28T21:56:17Z.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ja;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::ja::ISA = qw(DateTime::Locale::root);

my @day_names = (
"月曜日",
"火曜日",
"水曜日",
"木曜日",
"金曜日",
"土曜日",
"日曜日",
);

my @day_abbreviations = (
"月",
"火",
"水",
"木",
"金",
"土",
"日",
);

my @day_narrows = (
"月",
"火",
"水",
"木",
"金",
"土",
"日",
);

my @month_names = (
"1月",
"2月",
"3月",
"4月",
"5月",
"6月",
"7月",
"8月",
"9月",
"10月",
"11月",
"12月",
);

my @am_pms = (
"午前",
"午後",
);

my @eras = (
"紀元前",
"西暦",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%\{ce_year\}年\%\{month\}月\%\{day\}日\%A" }
sub long_date_format               { "\%\{ce_year\}年\%\{month\}月\%\{day\}日" }
sub medium_date_format             { "\%\{ce_year\}\/\%m\/\%d" }
sub full_time_format               { "\%\{hour\}時\%M分\%S秒\%\{time_zone_long_name\}" }
sub long_time_format               { "\%\{hour\}\:\%M\:\%S\:\%\{time_zone_long_name\}" }
sub medium_time_format             { "\%\{hour\}\:\%M\:\%S" }
sub short_time_format              { "\%\{hour\}\:\%M" }



1;

