###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ga.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ga;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::ga::ISA = qw(DateTime::Locale::root);

my @day_names = (
"Dé\ Luain",
"Dé\ Máirt",
"Dé\ Céadaoin",
"Déardaoin",
"Dé\ hAoine",
"Dé\ Sathairn",
"Dé\ Domhnaigh",
);

my @day_abbreviations = (
"Luan",
"Máirt",
"Céad",
"Déar",
"Aoine",
"Sath",
"Domh",
);

my @month_names = (
"Eanáir",
"Feabhra",
"Márta",
"Aibreán",
"Bealtaine",
"Meitheamh",
"Iúil",
"Lúnasa",
"Meán\ Fómhair",
"Deireadh\ Fómhair",
"Samhain",
"Nollaig",
);

my @month_abbreviations = (
"Ean",
"Feabh",
"Márta",
"Aib",
"Beal",
"Meith",
"Iúil",
"Lún",
"MFómh",
"DFómh",
"Samh",
"Noll",
);

my @am_pms = (
"a\.m\.",
"p\.m\.",
);

my @eras = (
"RC",
"AD",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }



1;

