###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file byn.xml.
# The source file version number was 1.2, generated on
# 2004-06-04.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::byn;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::byn::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ሰኑ",
"ሰሊጝ",
"ለጓ\ ወሪ\ ለብዋ",
"ኣምድ",
"ኣርብ",
"ሰንበር\ ሽጓዅ",
"ሰንበር\ ቅዳዅ",
);

my @day_abbreviations = (
"ሰኑ",
"ሰሊጝ",
"ለጓ",
"ኣምድ",
"ኣርብ",
"ሰ\/ሽ",
"ሰ\/ቅ",
);

my @month_names = (
"ልደትሪ",
"ካብኽብቲ",
"ክብላ",
"ፋጅኺሪ",
"ክቢቅሪ",
"ምኪኤል\ ትጓ̅ኒሪ",
"ኰርኩ",
"ማርያም\ ትሪ",
"ያኸኒ\ መሳቅለሪ",
"መተሉ",
"ምኪኤል\ መሽወሪ",
"ተሕሳስሪ",
);

my @month_abbreviations = (
"ልደት",
"ካብኽ",
"ክብላ",
"ፋጅኺ",
"ክቢቅ",
"ም\/ት",
"ኰር",
"ማርያ",
"ያኸኒ",
"መተሉ",
"ም\/ም",
"ተሕሳ",
);

my @am_pms = (
"ፋዱስ\ ጃብ",
"ፋዱስ\ ደምቢ",
);

my @eras = (
"ይጅ",
"ኣድ",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }



1;

