###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file or.xml.
# The source file version number was 1.0, generated on
# 2004-09-14.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::or;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::or::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ସୋମବାର",
"ମଙ୍ଗଳବାର",
"ବୁଧବାର",
"ଗୁରୁବାର",
"ଶୁକ୍ରବାର",
"ଶନିବାର",
"ରବିବାର",
);

my @day_abbreviations = (
"ସୋମ",
"ମଙ୍ଗଳ",
"ବୁଧ",
"ଗୁରୁ",
"ଶୁକ୍ର",
"ଶନି",
"ରବି",
);

my @month_names = (
"ଜାନୁଆରୀ",
"ଫେବ୍ରୁୟାରୀ",
"ମାର୍ଚ୍ଚ",
"ଅପ୍ରେଲ",
"ମେ",
"ଜୁନ",
"ଜୁଲାଇ",
"ଅଗଷ୍ଟ",
"ସେପ୍ଟେମ୍ବର",
"ଅକ୍ଟୋବର",
"ନଭେମ୍ବର",
"ଡିସେମ୍ବର",
);



sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }



1;

