###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file hr.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::hr;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::hr::ISA = qw(DateTime::Locale::root);

my @day_names = (
"ponedjeljak",
"utorak",
"srijeda",
"četvrtak",
"petak",
"subota",
"nedjelja",
);

my @day_abbreviations = (
"pon",
"uto",
"sri",
"čet",
"pet",
"sub",
"ned",
);

my @day_narrows = (
"p",
"u",
"s",
"č",
"p",
"s",
"n",
);

my @month_names = (
"siječnja",
"veljače",
"ožujka",
"travnja",
"svibnja",
"lipnja",
"srpnja",
"kolovoza",
"rujna",
"listopada",
"studenoga",
"prosinca",
);

my @month_abbreviations = (
"sij",
"vel",
"ožu",
"tra",
"svi",
"lip",
"srp",
"kol",
"ruj",
"lis",
"stu",
"pro",
);

my @month_narrows = (
"s",
"v",
"o",
"t",
"s",
"l",
"s",
"k",
"r",
"l",
"s",
"p",
);

my $date_parts_order = "ymd";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub day_narrows                    { \@day_narrows }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub month_narrows                  { \@month_narrows }
sub full_date_format               { "\%\{ce_year\}\.\ \%B\ \%d" }
sub long_date_format               { "\%\{ce_year\}\.\ \%B\ \%d" }
sub medium_date_format             { "\%\{ce_year\}\.\%m\.\%d" }
sub short_date_format              { "\%\{ce_year\}\.\%m\.\%d" }
sub date_parts_order               { $date_parts_order }



1;

