###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file sq.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::sq;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::root;

@DateTime::Locale::sq::ISA = qw(DateTime::Locale::root);

my @day_names = (
"e\ hënë",
"e\ martë",
"e\ mërkurë",
"e\ enjte",
"e\ premte",
"e\ shtunë",
"e\ diel",
);

my @day_abbreviations = (
"Hën",
"Mar",
"Mër",
"Enj",
"Pre",
"Sht",
"Die",
);

my @month_names = (
"janar",
"shkurt",
"mars",
"prill",
"maj",
"qershor",
"korrik",
"gusht",
"shtator",
"tetor",
"nëntor",
"dhjetor",
);

my @month_abbreviations = (
"Jan",
"Shk",
"Mar",
"Pri",
"Maj",
"Qer",
"Kor",
"Gsh",
"Sht",
"Tet",
"Nën",
"Dhj",
);

my @am_pms = (
"PD",
"MD",
);

my @eras = (
"p\.e\.r\.",
"n\.e\.r\.",
);

my $date_parts_order = "ymd";


sub day_names                      { \@day_names }
sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }
sub am_pms                         { \@am_pms }
sub eras                           { \@eras }
sub full_date_format               { "\%A\,\ \%d\ \%B\ \%\{ce_year\}" }
sub long_date_format               { "\%d\ \%B\ \%\{ce_year\}" }
sub medium_date_format             { "\%\{ce_year\}\-\%m\-\%d" }
sub short_date_format              { "\%y\-\%m\-\%d" }
sub full_time_format               { "\%\{hour_12\}\.\%M\.\%S\.\%p\ \%\{time_zone_long_name\}" }
sub long_time_format               { "\%\{hour_12\}\.\%M\.\%S\.\%p\ \%\{time_zone_long_name\}" }
sub medium_time_format             { "\%\{hour_12\}\:\%M\:\%S\.\%p" }
sub short_time_format              { "\%\{hour_12\}\.\%M\.\%p" }
sub date_parts_order               { $date_parts_order }



1;

