###########################################################################
#
# This file is auto-generated by the Perl DateTime Suite time locale
# generator (0.02).  This code generator comes with the
# DateTime::Locale distribution in the tools/ directory, and is called
# generate_from_icu.
#
# This file as generated from the ICU XML locale data.  See the
# LICENSE.icu file included in this distribution for license details.
#
# This file was generated from the source file ar_LB.xml.
# The source file version number was 1.2, generated on
# 2004-08-27.
#
# Do not edit this file directly.
#
###########################################################################

package DateTime::Locale::ar_LB;

use strict;

BEGIN
{
    if ( $] >= 5.006 )
    {
        require utf8; utf8->import;
    }
}

use DateTime::Locale::ar;

@DateTime::Locale::ar_LB::ISA = qw(DateTime::Locale::ar);

my @day_abbreviations = (
"الاثنين",
"الثلاثاء",
"الأربعاء",
"الخميس",
"الجمعة",
"السبت",
"الأحد",
);

my @month_names = (
"كانون\ الثاني",
"شباط",
"آذار",
"نيسان",
"نوار",
"حزيران",
"تموز",
"آب",
"أيلول",
"تشرين\ الأول",
"تشرين\ الثاني",
"كانون\ الأول",
);

my @month_abbreviations = (
"كانون\ الثاني",
"شباط",
"آذار",
"نيسان",
"نوار",
"حزيران",
"تموز",
"آب",
"أيلول",
"تشرين\ الأول",
"تشرين\ الثاني",
"كانون\ الأول",
);



sub day_abbreviations              { \@day_abbreviations }
sub month_names                    { \@month_names }
sub month_abbreviations            { \@month_abbreviations }



1;

